#  -*- coding: utf-8 -*-
# Copyright (c) 2025/9/4 cuba3. All rights reserved.
# @Time: 2025/9/4 16:14
# @Author: cuba3
# @Email: cuba3@163.com
# @File: __init__.py
# @Organizations: OPN48
from cntc260.tc260 import GBxmp